Crosswalks column names of the POLIS pop dataset
crosswalk_pop_cols.RdCrosswalks the original column names of the POLIS pop dataset so that it is compatible with the names used by the data cleaning scripts developed within CDC. The function also filters for the only columns used in the population datasets and adds new columns, such as the adm0-2guids. In addition, the tables get transformed by pivoting wider using the AgeGroupCode.
Examples
if (FALSE) { # \dontrun{
dist_pop <- load_polis_pop("dist")
dist_pop <- crosswalk_pop_cols(dist_pop)
} # }