Load population growth rates
load_growth_rates.RdLoad population growth rates
Usage
load_growth_rates(
.file_loc =
"GID/PEB/SIR/Data/pop/pop raw/WPP2024_GEN_F01_DEMOGRAPHIC_INDICATORS_COMPACT.xlsx",
edav = TRUE
)Details
Loads and formats the population growth rate file for use in R.
The Excel file uses the "Estimates" tab. The first few rows (16 rows or so) are deleted for ease of loading into R. The source of this dataset is in the World Population Prospects website, using the "Compact" file.