Create a map to check for population outliers
map_pop_outlier.RdMaps the percentage of change in population over years to check for outliers in the population data. This is a diagnostic tool.
Arguments
- pop_w_outlier_cat
tibbleOutput ofdetect_processed_pop_outliers().- sf_long
sfShapefile in long format. Any of the sirfunctions::load_clean_*_sp(type = "long"), as long as the administrative level is the same as the population file.- pop_cat
strPopulation category to map. Either u15, u5, or totpop.- ctry_name
strOptional country name.- who_region
strOptional region name.- year_end
intYear end. Defaults to current year.- year_start
intYear start. Defaults to four years ago from the end year.